==> builders_inventory-2.2.4-sources.jar: _3650/builders_inventory/feature/extended_inventory/ExtendedInventoryDeleteScreen.java <==
package _3650.builders_inventory.feature.extended_inventory;

import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.List;
import java.util.Locale;
import net.minecraft.class_124;
import net.minecraft.class_156;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_364;
import net.minecraft.class_4068;
import net.minecraft.class_437;
import net.minecraft.class_6379;
import net.minecraft.class_8016;
import net.minecraft.class_8023;
import net.minecraft.class_8666;
import org.jetbrains.annotations.Nullable;

import _3650.builders_inventory.BuildersInventory;
import _3650.builders_inventory.ModKeybinds;
import _3650.builders_inventory.api.util.GuiUtil;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButton;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButtonGui;
import _3650.builders_inventory.config.Config;

public class ExtendedInventoryDeleteScreen extends class_437 {
	
	public static final DecimalFormat TIMER_FORMAT = class_156.method_654(
		new DecimalFormat("0.0"), decimalFormat -> decimalFormat.setDecimalFormatSymbols(DecimalFormatSymbols.getInstance(Locale.ROOT))
	);
	
	private static final class_2960 BACKGROUND = BuildersInventory.modLoc("textures/gui/container/extended_inventory/delete.png");
	
	private static final class_8666 SPRITES_BUTTON_DELETE = new class_8666(
			BuildersInventory.modLoc("extended_inventory/delete/button_delete"),
			BuildersInventory.modLoc("extended_inventory/delete/button_delete_disabled"),
			BuildersInventory.modLoc("extended_inventory/delete/button_delete_highlighted"));
	private static final class_8666 SPRITES_BUTTON_CANCEL = new class_8666(
			BuildersInventory.modLoc("extended_inventory/delete/button_cancel"),
			BuildersInventory.modLoc("extended_inventory/delete/button_cancel_highlighted"));
	
	private final ExtendedImageButtonGui exGui = new ExtendedImageButtonGui();
	private final int imageWidth;
	private final int imageHeight;
	
	private int leftPos;
	private int topPos;
	
	private final ExtendedInventoryPage page;
	private final int pageIndex;
	
	private final long enableTimer;
	private ExtendedImageButton deleteButton;
	private ExtendedImageButton cancelButton;
	
	public ExtendedInventoryDeleteScreen(int page) {
		super(class_2561.method_43469("container.builders_inventory.extended_inventory.delete", page + 1));
		this.page = ExtendedInventoryPages.get(page);
		this.pageIndex = page;
		this.imageWidth = 179;
		this.imageHeight = 161;
		this.enableTimer = class_156.method_658() + 3500L;
		this.createButtons();
	}
	
	@Override
	protected void method_25426() {
		super.method_25426();
		this.exGui.init();
		this.leftPos = (this.field_22789 - this.imageWidth) / 2;
		this.topPos = (this.field_22790 - this.imageHeight) / 2;
		
		this.createButtons();
		this.method_37063(this.deleteButton);
		this.method_37063(this.cancelButton);
	}
	
	private void createButtons() {
		this.deleteButton = new ExtendedImageButton(this.leftPos + 77, this.topPos + 129, 26, 26,
				() -> List.of(class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete").method_27692(class_124.field_1068),
						class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete.desc").method_27692(class_124.field_1061),
						class_2561.method_43469("container.builders_inventory.extended_inventory.delete.tooltip.button.delete.desc.disabled",
								TIMER_FORMAT.format(Math.max(0L, this.enableTimer - class_156.method_658()) / 1000.0)).method_27692(class_124.field_1080)),
				SPRITES_BUTTON_DELETE,
				button -> {
					ExtendedInventoryPages.delete(this.pageIndex);
					ExtendedInventory.setPage(Math.min(ExtendedInventoryPages.size() - 1, this.pageIndex));
					ExtendedInventory.open(this.field_22787);
				},
				List.of(class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete").method_27692(class_124.field_1068),
						class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete.desc").method_27692(class_124.field_1061))
				) {
			@Nullable
			@Override
			public class_8016 method_48205(class_8023 event) {
				return null;
			}
		};
		this.deleteButton.field_22763 = false;
		this.cancelButton = new ExtendedImageButton(this.leftPos + 110, this.topPos + 135, 14, 14,
				SPRITES_BUTTON_CANCEL,
				button -> {
					ExtendedInventory.open(this.field_22787);
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.cancel").method_27692(class_124.field_1068),
				class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.cancel.desc").method_27692(class_124.field_1080));
	}
	
	@Override
	protected <T extends class_364 & class_4068 & class_6379> T method_37063(T widget) {
		this.exGui.addRenderableWidget(widget);
		return super.method_37063(widget);
	}
	
	@Override
	protected void method_37067() {
		this.exGui.clearWidgets();
		super.method_37067();
	}
	
	@Override
	public void method_25394(class_332 gui, int mouseX, int mouseY, float partialTick) {
		super.method_25394(gui, mouseX, mouseY, partialTick);
		gui.method_51439(this.field_22793, this.field_22785, this.leftPos + 8, this.topPos + 6, 0xFF404040, false);
		
		int x = this.leftPos + 10;
		int y = this.topPos + 18;
		int slot = 0;
		for (int row = 0; row < 6; row++) {
			int slotY = y + (row * 18);
			for (int col = 0; col < 9; col++) {
				int slotX = x + (col * 18);
				class_1799 stack = this.page.get(slot++);
				gui.method_51427(stack, slotX, slotY);
				gui.method_51431(this.field_22793, stack, slotX, slotY);
			}
		}
		
		this.deleteButton.field_22763 = class_156.method_658() > this.enableTimer;
		
		this.exGui.renderTooltip(this.field_22793, gui, mouseX, mouseY);
	}
	
	@Override
	public void method_25420(class_332 gui, int mouseX, int mouseY, float partialTick) {
		this.method_52752(gui);
		GuiUtil.blitScreenBackground(gui, BACKGROUND, this.leftPos, this.topPos, this.imageWidth, this.imageHeight);
	}
	
	@Override
	public boolean method_25404(int keyCode, int scanCode, int modifiers) {
		if (this.field_22787.field_1690.field_1822.method_1417(keyCode, scanCode)) {
			this.method_25419();
			return true;
		} else if (ModKeybinds.OPEN_EXTENDED_INVENTORY.method_1417(keyCode, scanCode)) {
			ExtendedInventory.open(this.field_22787);
			return true;
		} else return super.method_25404(keyCode, scanCode, modifiers);
	}
	
	@Override
	public void method_25419() {
		if (Config.instance().extended_inventory_close_to_main) {
			ExtendedInventory.open(this.field_22787);
		} else super.method_25419();
	}
	
	@Override
	public boolean method_25421() {
		return false;
	}
	
}

==> builders_inventory-2.2.6-sources.jar: _3650/builders_inventory/feature/extended_inventory/ExtendedInventoryDeleteScreen.java <==
package _3650.builders_inventory.feature.extended_inventory;

import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.List;
import java.util.Locale;
import net.minecraft.class_11908;
import net.minecraft.class_124;
import net.minecraft.class_156;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_364;
import net.minecraft.class_4068;
import net.minecraft.class_437;
import net.minecraft.class_6379;
import net.minecraft.class_8016;
import net.minecraft.class_8023;
import net.minecraft.class_8666;
import org.jetbrains.annotations.Nullable;

import _3650.builders_inventory.BuildersInventory;
import _3650.builders_inventory.ModKeybinds;
import _3650.builders_inventory.api.util.GuiUtil;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButton;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButtonGui;
import _3650.builders_inventory.config.Config;

public class ExtendedInventoryDeleteScreen extends class_437 {
	
	public static final DecimalFormat TIMER_FORMAT = class_156.method_654(
		new DecimalFormat("0.0"), decimalFormat -> decimalFormat.setDecimalFormatSymbols(DecimalFormatSymbols.getInstance(Locale.ROOT))
	);
	
	private static final class_2960 BACKGROUND = BuildersInventory.modLoc("textures/gui/container/extended_inventory/delete.png");
	
	private static final class_8666 SPRITES_BUTTON_DELETE = new class_8666(
			BuildersInventory.modLoc("extended_inventory/delete/button_delete"),
			BuildersInventory.modLoc("extended_inventory/delete/button_delete_disabled"),
			BuildersInventory.modLoc("extended_inventory/delete/button_delete_highlighted"));
	private static final class_8666 SPRITES_BUTTON_CANCEL = new class_8666(
			BuildersInventory.modLoc("extended_inventory/delete/button_cancel"),
			BuildersInventory.modLoc("extended_inventory/delete/button_cancel_highlighted"));
	
	private final ExtendedImageButtonGui exGui = new ExtendedImageButtonGui();
	private final int imageWidth;
	private final int imageHeight;
	
	private int leftPos;
	private int topPos;
	
	private final ExtendedInventoryPage page;
	private final int pageIndex;
	
	private final long enableTimer;
	private ExtendedImageButton deleteButton;
	private ExtendedImageButton cancelButton;
	
	public ExtendedInventoryDeleteScreen(int page) {
		super(class_2561.method_43469("container.builders_inventory.extended_inventory.delete", page + 1));
		this.page = ExtendedInventoryPages.get(page);
		this.pageIndex = page;
		this.imageWidth = 179;
		this.imageHeight = 161;
		this.enableTimer = class_156.method_658() + 3500L;
		this.createButtons();
	}
	
	@Override
	protected void method_25426() {
		super.method_25426();
		this.exGui.init();
		this.leftPos = (this.field_22789 - this.imageWidth) / 2;
		this.topPos = (this.field_22790 - this.imageHeight) / 2;
		
		this.createButtons();
		this.method_37063(this.deleteButton);
		this.method_37063(this.cancelButton);
	}
	
	private void createButtons() {
		this.deleteButton = new ExtendedImageButton(this.leftPos + 77, this.topPos + 129, 26, 26,
				() -> List.of(class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete").method_27692(class_124.field_1068),
						class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete.desc").method_27692(class_124.field_1061),
						class_2561.method_43469("container.builders_inventory.extended_inventory.delete.tooltip.button.delete.desc.disabled",
								TIMER_FORMAT.format(Math.max(0L, this.enableTimer - class_156.method_658()) / 1000.0)).method_27692(class_124.field_1080)),
				SPRITES_BUTTON_DELETE,
				(button, input) -> {
					ExtendedInventoryPages.delete(this.pageIndex);
					ExtendedInventory.setPage(Math.min(ExtendedInventoryPages.size() - 1, this.pageIndex));
					ExtendedInventory.open(this.field_22787);
				},
				List.of(class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete").method_27692(class_124.field_1068),
						class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.delete.desc").method_27692(class_124.field_1061))
				) {
			@Nullable
			@Override
			public class_8016 method_48205(class_8023 event) {
				return null;
			}
		};
		this.deleteButton.field_22763 = false;
		this.cancelButton = new ExtendedImageButton(this.leftPos + 110, this.topPos + 135, 14, 14,
				SPRITES_BUTTON_CANCEL,
				(button, input) -> {
					ExtendedInventory.open(this.field_22787);
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.cancel").method_27692(class_124.field_1068),
				class_2561.method_43471("container.builders_inventory.extended_inventory.delete.tooltip.button.cancel.desc").method_27692(class_124.field_1080));
	}
	
	@Override
	protected <T extends class_364 & class_4068 & class_6379> T method_37063(T widget) {
		this.exGui.addRenderableWidget(widget);
		return super.method_37063(widget);
	}
	
	@Override
	protected void method_37067() {
		this.exGui.clearWidgets();
		super.method_37067();
	}
	
	@Override
	public void method_25394(class_332 gui, int mouseX, int mouseY, float partialTick) {
		super.method_25394(gui, mouseX, mouseY, partialTick);
		gui.method_51439(this.field_22793, this.field_22785, this.leftPos + 8, this.topPos + 6, 0xFF404040, false);
		
		int x = this.leftPos + 10;
		int y = this.topPos + 18;
		int slot = 0;
		for (int row = 0; row < 6; row++) {
			int slotY = y + (row * 18);
			for (int col = 0; col < 9; col++) {
				int slotX = x + (col * 18);
				class_1799 stack = this.page.get(slot++);
				gui.method_51427(stack, slotX, slotY);
				gui.method_51431(this.field_22793, stack, slotX, slotY);
			}
		}
		
		this.deleteButton.field_22763 = class_156.method_658() > this.enableTimer;
		
		this.exGui.renderTooltip(this.field_22793, gui, mouseX, mouseY);
	}
	
	@Override
	public void method_25420(class_332 gui, int mouseX, int mouseY, float partialTick) {
		this.method_52752(gui);
		GuiUtil.blitScreenBackground(gui, BACKGROUND, this.leftPos, this.topPos, this.imageWidth, this.imageHeight);
	}
	
	@Override
	public boolean method_25404(class_11908 event) {
		if (this.field_22787.field_1690.field_1822.method_1417(event)) {
			this.method_25419();
			return true;
		} else if (ModKeybinds.OPEN_EXTENDED_INVENTORY.method_1417(event)) {
			ExtendedInventory.open(this.field_22787);
			return true;
		} else return super.method_25404(event);
	}
	
	@Override
	public void method_25419() {
		if (Config.instance().extended_inventory_close_to_main) {
			ExtendedInventory.open(this.field_22787);
		} else super.method_25419();
	}
	
	@Override
	public boolean method_25421() {
		return false;
	}
	
}
